
    // Disable workers to avoid yet another cross-origin issue (workers need the URL of
    // the script to be loaded, and currently do not allow cross-origin scripts)
    //
    PDFJS.disableWorker = true;

    var pdfDoc = null,
        pageNum = 1,
        pageRendering = false,
        pageNumPending = null,
        scale = 1.0,
        canvas = document.getElementById('the-canvas'),
        ctx = canvas.getContext('2d');

    function loadPdfFile(filePath, showFromLastPage){
        if(typeof showFromLastPage === 'undefined') showFromLastPage = false;
        url = filePath;
        PDFJS.getDocument(url).then(function getPdf(pdfDoc_) {
              pdfDoc = pdfDoc_;
              var totalPages = pdfDoc.numPages;
              document.getElementById('page_count').textContent = totalPages;
              if(showFromLastPage){
                pageNum = totalPages;
              }
              Android.pageCount(totalPages, pageNum);
              renderPage(pageNum);
        });
    }

    /**
     * Get page info from document, resize canvas accordingly, and render page.
     * @param num Page number.
     */
    function renderPage(num) {
      pageRendering = true;
      // Using promise to fetch the page
      pdfDoc.getPage(num).then(function(page) {

        var viewport = page.getViewport(scale);
        canvas.height = viewport.height;
        canvas.width = viewport.width;

        // Render PDF page into canvas context
        var renderContext = {
          canvasContext: ctx,
          viewport: viewport
        };
        var renderTask = page.render(renderContext);
        Android.onPageLoadStarted();
        // Wait for rendering to finish
        renderTask.promise.then(function () {
        Android.onPageLoadFinished();
          pageRendering = false;
          if (pageNumPending !== null) {
            // New page rendering is pending
            renderPage(pageNumPending);
            pageNumPending = null;
          }
        });
      });

      // Update page counters
      document.getElementById('page_num').textContent = pageNum;
    }
    
    /**
     * If another page rendering in progress, waits until the rendering is
     * finished. Otherwise, executes rendering immediately.
     */
    function queueRenderPage(num) {
      if (pageRendering) {
        pageNumPending = num;
      } else {
        renderPage(num);
      }
    }

    /**
     * Displays previous page.
     */
    function onPrevPage() {
      if (pageNum <= 1) {
        return;
      }
      pageNum--;
      queueRenderPage(pageNum);
    }

    /**
     * Displays next page.
     */
    function onNextPage() {
      if (pageNum >= pdfDoc.numPages) {
        return;
      }
      pageNum++;
      queueRenderPage(pageNum);
    }
    

    function getParameterByName(name) {
        name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
        var regex = new RegExp("[\\?&]" + name + "=([^&#]*)"),
            results = regex.exec(location.search);
        return results === null ? "" : decodeURIComponent(results[1].replace(/\+/g, " "));
    }

//    /**
//     * Asynchronously downloads PDF.
//     */
//    PDFJS.getDocument(url).then(function getPdf(pdfDoc_) {
//      pdfDoc = pdfDoc_;
//      document.getElementById('page_count').textContent = pdfDoc.numPages;
//      Android.pageCount(pdfDoc.numPages);
//      // Initial/first page rendering
//      renderPage(pageNum);
//    });